%define         dlver 2023-05-17

Name:           neomutt
Version:        %(echo %{dlver} | sed -s 's|-||g')
Release:        %mkrel 1
Summary:        A command line mail reader based on Mutt
Group:          Networking/Mail
License:        GPLv2
URL:            https://www.neomutt.org/
Source0:        https://github.com/neomutt/neomutt/archive/%{version}/%{name}-%{version}.tar.gz
# Add file from git master
Source1:        https://github.com/neomutt/neomutt/raw/main/auto.def#/auto-%{version}.def

Patch0:         neomutt-program-prefix.patch

BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(lua) >= 5.3
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libidn2)
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(kyotocabinet)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  gpgme-devel
BuildRequires:  doxygen
BuildRequires:  xsltproc
BuildRequires:  docbook-dtds
BuildRequires:  docbook-style-xsl
BuildRequires:  docbook-utils
BuildRequires:  linuxdoc-tools
BuildRequires:  db-devel >= 5.3
Requires:       urlview
Requires:       sasl-plug-login
Requires:	sasl-plug-gssapi
Recommends:     mailcap
Recommends:     neomutt-doc = %{version}-%{release}

%description
What is NeoMutt?

    NeoMutt is a project of projects.
    A place to gather all the patches against Mutt.
    A place for all the developers to gather.

Hopefully this will build the community and reduce duplicated effort.

NeoMutt was created when Richard Russon (FlatCap) took all the old Mutt
patches, sorted through them, fixed them up and documented them.

%package doc
Summary:        Documentation and examples for NeoMutt
BuildArch:      noarch

%description doc
This package contains the documentation and examples for NeoMutt.

%prep
%autosetup -p1 -n %{name}-%{version}

cp %{S:1} auto.def

%build
#set_build_flags
%configure \
    --lua \
    --gpgme \
    --full-doc \
    --gnutls \
    --gss \
    --ssl \
    --docdir=%{_docdir}/%{name}-doc \
    --bdb \
    --pgp \
    --smime \
    --locales-fix \
    --sasl \
    --idn2 \
    --disable-idn \
    --libdir=%{_libdir} \
    --disable-maintainer-mode \
    --disable-dependency-tracking \
    --kyotocabinet \
    --with-ui \
    --with-sqlite=%{_libdir} \
    --with-lock

# neomutt automatically adds /lib and /usr/lib regardless of arch, so this fixes it
sed -i "s|L/lib|L/%{_lib}|g" Makefile
sed -i "s|L/usr/lib|L/usr/%{_lib}|g" Makefile

%make_build

%install
%make_install

%find_lang %{name}

%files -f %{name}.lang
%doc README.* ChangeLog.md
%config(noreplace) %{_sysconfdir}/neomuttrc
%{_bindir}/neomutt
%{_libexecdir}/%{name}/*
%{_mandir}/man1/*.1*
%{_mandir}/man5/*.5*
%{_datadir}/%{name}

%files doc
%{_docdir}/%{name}-doc/


%changelog
* Mon Jul 03 2023 bcornec <bcornec> 20230517-1.mga8
+ Revision: 1963526
- Update neomutt to upstream 20230517 to fix CVE-2021-32055 and CVE-2022-1328 mga#30292
+ kekepower <kekepower>
- Update to version 2022-04-15 to fix CVE-2022-1328 (mga#30292)

* Fri Feb 05 2021 kekepower <kekepower> 20210205-1.mga8
+ Revision: 1674911
- Update to release 20210205

* Fri Nov 27 2020 kekepower <kekepower> 20201127-1.mga8
+ Revision: 1649731
- Update to release 20201127

* Fri Nov 20 2020 kekepower <kekepower> 20201120-1.mga8
+ Revision: 1647998
- Update to release 20201120

* Sat Sep 26 2020 kekepower <kekepower> 20200925-1.mga8
+ Revision: 1630654
- Update to version 20200925

* Fri Aug 21 2020 kekepower <kekepower> 20200821-1.mga8
+ Revision: 1617726
- Update to version 20200821
+ ovitters <ovitters>
- switch url to http, https gives certificate error

* Sun Aug 16 2020 kekepower <kekepower> 20200814-1.mga8
+ Revision: 1614293
- Update to version 20200814

* Sun Jun 28 2020 kekepower <kekepower> 20200626-1.mga8
+ Revision: 1600122
- Update to version 20200626

* Fri Jun 19 2020 kekepower <kekepower> 20200619-1.mga8
+ Revision: 1597400
- Update to version 20200619
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Fri May 01 2020 kekepower <kekepower> 20200501-1.mga8
+ Revision: 1577625
- Update to version 20200501

* Fri Apr 24 2020 kekepower <kekepower> 20200424-1.mga8
+ Revision: 1571760
- Update to release 20200424

* Sun Apr 19 2020 kekepower <kekepower> 20200417-1.mga8
+ Revision: 1569713
- Update to version 20200417

* Fri Mar 13 2020 kekepower <kekepower> 20200313-1.mga8
+ Revision: 1556129
- Update to release 20200313

* Thu Mar 05 2020 kekepower <kekepower> 20191207-2.mga8
+ Revision: 1553995
- Revert changes in r1553988

* Thu Mar 05 2020 umeabot <umeabot> 20191207-0.2.mga8
+ Revision: 1553988
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Dec 08 2019 kekepower <kekepower> 20191207-0.1.mga8
+ Revision: 1465205
- Update to release 20191207

* Sat Nov 30 2019 kekepower <kekepower> 20191129-0.1.mga8
+ Revision: 1463840
- Update to release 20191129

* Tue Nov 12 2019 kekepower <kekepower> 20191111-0.1.mga8
+ Revision: 1459539
- Update to release 20191111

* Sat Nov 02 2019 kekepower <kekepower> 20191102-0.1.mga8
+ Revision: 1457305
- Update to release 20191102

* Mon Oct 28 2019 kekepower <kekepower> 20191025-0.1.mga8
+ Revision: 1456310
- Update to release 2019-10-25

* Wed Feb 13 2019 luigiwalser <luigiwalser> 20180716-0.4.mga7
+ Revision: 1366531
- rebuild for libidn2

* Wed Jan 09 2019 wally <wally> 20180716-0.3.mga7
+ Revision: 1353603
- rebuild for new libidn2

* Sun Sep 23 2018 umeabot <umeabot> 20180716-0.2.mga7
+ Revision: 1299696
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 kekepower <kekepower> 20180716-0.1.mga7
+ Revision: 1248797
- Update to release 20180716

* Fri Jun 22 2018 kekepower <kekepower> 20180622-0.2.mga7
+ Revision: 1239075
- Fix Requires for sasl-plugins

* Fri Jun 22 2018 kekepower <kekepower> 20180622-0.1.mga7
+ Revision: 1238867
- Update to release 20180622

* Sat Jun 09 2018 kekepower <kekepower> 20180512-0.3.mga7
+ Revision: 1235643
- BR krb53-devel
- Enable gss

* Thu May 24 2018 kekepower <kekepower> 20180512-0.2.mga7
+ Revision: 1232067
- Build with idn2 and disable idn

* Sat May 12 2018 kekepower <kekepower> 20180512-0.1.mga7
+ Revision: 1228456
- Update to release 20180512

* Fri May 11 2018 kekepower <kekepower> 20180323-0.2.mga7
+ Revision: 1228383
- Rebuild for libidn 1.35

* Fri Apr 27 2018 kekepower <kekepower> 20180323-0.1.mga7
+ Revision: 1222911
- Update to version 20180323
- Update BRs
- Fix file lists
+ diogoleal <diogoleal>
- added neomutt spec file
- Created package structure for neomutt.

